@@ -10,7 +10,7 @@ use Carp;
 use List::Util qw(all);
 use Scalar::Util::Numeric qw(isint);
 
-our $VERSION = '0.0107'; # VERSION
+our $VERSION = '0.0108'; # VERSION
 
 require XSLoader;
 XSLoader::load('Crypt::XTEA', $VERSION);
@@ -23,10 +23,10 @@ my $BLOCK_SIZE = 8;
 my $ELEMENTS_IN_BLOCK = $BLOCK_SIZE / 4;
 
 
-use constant keysize => $KEY_SIZE;
+sub keysize { $KEY_SIZE }
 
 
-use constant blocksize => $BLOCK_SIZE;
+sub blocksize { $BLOCK_SIZE }
 
 
 sub new {
@@ -119,7 +119,7 @@ Crypt::XTEA - Implementation of the eXtended Tiny Encryption Algorithm
 
 =head1 VERSION
 
-version 0.0107
+version 0.0108
 
 =head1 SYNOPSIS
 
